@@ -1166,7 +1166,10 @@ gnome_desktop_file_get_locale_string (GnomeDesktopFile  *df,
   g_free (with_territory);
 
   if (raw == NULL)
-    return FALSE;
+    {
+      g_free (used_locale);
+      return FALSE;
+    }
   
   if (gnome_desktop_file_get_encoding (df) == GNOME_DESKTOP_FILE_ENCODING_UTF8)
     {
@@ -1181,12 +1184,12 @@ gnome_desktop_file_get_locale_string (GnomeDesktopFile  *df,
           const char *encoding;
           
 	  encoding = desktop_file_get_encoding_for_locale (used_locale);
-          g_free (used_locale);
           
 	  if (encoding)
 	    {
               char *res;
               
+              g_free (used_locale);
 	      error = NULL;
 	      res = g_convert (raw, -1,            
 			       "UTF-8",
@@ -1226,6 +1229,7 @@ gnome_desktop_file_get_locale_string (GnomeDesktopFile  *df,
   else
     {
       g_printerr ("Desktop file doesn't have its encoding marked, can't parse it.\n");
+      g_free (used_locale);
       return FALSE;
     }
 }
@@ -1479,15 +1483,15 @@ struct {
   const char *encoding;
   const char *langs[N_LANG];
 } known_encodings[] = {
-  {"ARMSCII-8", {"by"}},
+  {"ARMSCII-8", {"hy"}},
   {"BIG5", {"zh_TW"}},
   {"CP1251", {"be", "bg"}},
-  {"EUC-CN", {"zh_TW"}},
+  {"EUC-CN", {"zh_CN"}},
   {"EUC-JP", {"ja"}},
   {"EUC-KR", {"ko"}},
   {"GEORGIAN-ACADEMY", {}},
   {"GEORGIAN-PS", {"ka"}},
-  {"ISO-8859-1", {"br", "ca", "da", "de", "en", "es", "eu", "fi", "fr", "gl", "it", "nl", "wa", "no", "pt", "pt", "sv"}},
+  {"ISO-8859-1", {"br", "ca", "da", "de", "en", "es", "eu", "fi", "fr", "gl", "it", "nl", "no", "pt", "sv", "wa" }},
   {"ISO-8859-2", {"cs", "hr", "hu", "pl", "ro", "sk", "sl", "sq", "sr"}},
   {"ISO-8859-3", {"eo"}},
   {"ISO-8859-5", {"mk", "sp"}},
